You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by rj...@apache.org on 2006/09/13 20:08:48 UTC

svn commit: r443049 - /tomcat/connectors/trunk/jk/native/common/jk_lb_worker.c

Author: rjung
Date: Wed Sep 13 11:08:47 2006
New Revision: 443049

URL: http://svn.apache.org/viewvc?view=rev&rev=443049
Log:
Fix comments and log message according to make it fit to the previous commit.

Modified:
    tomcat/connectors/trunk/jk/native/common/jk_lb_worker.c

Modified: tomcat/connectors/trunk/jk/native/common/jk_lb_worker.c
URL: http://svn.apache.org/viewvc/tomcat/connectors/trunk/jk/native/common/jk_lb_worker.c?view=diff&rev=443049&r1=443048&r2=443049
==============================================================================
--- tomcat/connectors/trunk/jk/native/common/jk_lb_worker.c (original)
+++ tomcat/connectors/trunk/jk/native/common/jk_lb_worker.c Wed Sep 13 11:08:47 2006
@@ -960,8 +960,8 @@
             /* NULL record, no more workers left ... */
             if (!was_forced) {
                 int nf;
                 /* Force recovery only on first attempt.
                  * If the second fails, Tomcat is still disconnected.
                  */
                 jk_shm_lock();
                 nf = force_recovery(p->worker, l);
@@ -974,7 +974,7 @@
                     prec = NULL;
                     rc   = -1;
                     jk_log(l, JK_LOG_INFO,
-                           "Forcing recovery on first attempt for %d workers", nf);
+                           "Forcing recovery once for %d workers", nf);
                     continue;
                 }
                 else {



---------------------------------------------------------------------
@@ -960,8 +960,8 @@
             if (!was_forced) {
                 int nf;
-                /* Force recovery only on first attempt.
-                 * If the second fails, Tomcat is still disconnected.
+                /* Force recovery only once.
+                 * If it still fails, Tomcat is still disconnected.
                  */
                 jk_shm_lock();
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org